@@ -3,17 +3,21 @@
 """Tests for `acdh_collatex_utils` package."""
 
 import glob
+import os
 import unittest
-from click.testing import CliRunner
 
 from acdh_collatex_utils.acdh_collatex_utils import *
-from acdh_collatex_utils import cli
 
 FILES = glob.glob(
     "./fixtures/*.xml",
     recursive=False
 )
 
+OUT_FILES = glob.glob(
+    "./fixtures/out__*.*",
+    recursive=False
+)
+
 
 class TestAcdh_collatex_utils(unittest.TestCase):
     """Tests for `acdh_collatex_utils` package."""
@@ -40,12 +44,24 @@ class TestAcdh_collatex_utils(unittest.TestCase):
             self.assertFalse('<lb break' in f"{doc.preprocess()}")
             self.assertTrue('<lb' in f"{doc.preprocess()}")
 
-    def test_command_line_interface(self):
-        """Test the CLI."""
-        runner = CliRunner()
-        result = runner.invoke(cli.main)
-        assert result.exit_code == 0
-        assert 'acdh_collatex_utils.cli.main' in result.output
-        help_result = runner.invoke(cli.main, ['--help'])
-        assert help_result.exit_code == 0
-        assert '--help  Show this message and exit.' in help_result.output
+    def test_003_chunks_to_df(self):
+        df = chunks_to_df(FILES)
+        self.assertTrue('id' in df.keys())
+
+    def test_004_collate_chunks(self):
+        if len(OUT_FILES) > 0:
+            for x in OUT_FILES:
+                os.remove(x)
+        out = CxCollate(output_dir='./fixtures').collate()
+        new_htmls = glob.glob(
+            "./fixtures/*.html",
+            recursive=False
+        )
+        self.assertTrue(len(new_htmls) == 3)
+        cur_out_files = glob.glob(
+            "./fixtures/out__*.*",
+            recursive=False
+        )
+        if len(cur_out_files) > 0:
+            for x in cur_out_files:
+                os.remove(x)
